==> zio-aws-wafregional_3-5.17.121.3-sources.jar: zio/aws/wafregional/model/DeleteRateBasedRuleResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.ChangeToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DeleteRateBasedRuleResponse(
    changeToken: Option[ChangeToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse = {
    import DeleteRateBasedRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse
      .builder()
      .optionallyWith(
        changeToken.map(value => ChangeToken.unwrap(value): java.lang.String)
      )(_.changeToken)
      .build()
  }
  def asReadOnly
      : zio.aws.wafregional.model.DeleteRateBasedRuleResponse.ReadOnly =
    zio.aws.wafregional.model.DeleteRateBasedRuleResponse.wrap(buildAwsValue())
}
object DeleteRateBasedRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.DeleteRateBasedRuleResponse =
      zio.aws.wafregional.model
        .DeleteRateBasedRuleResponse(changeToken.map(value => value))
    def changeToken: Option[ChangeToken]
    def getChangeToken: ZIO[Any, AwsError, ChangeToken] =
      AwsError.unwrapOptionField("changeToken", changeToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse
  ) extends zio.aws.wafregional.model.DeleteRateBasedRuleResponse.ReadOnly {
    override val changeToken: Option[ChangeToken] = scala
      .Option(impl.changeToken())
      .map(value => zio.aws.wafregional.model.primitives.ChangeToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse
  ): zio.aws.wafregional.model.DeleteRateBasedRuleResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-wafregional_3-5.19.31.2-sources.jar: zio/aws/wafregional/model/DeleteRateBasedRuleResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.ChangeToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeleteRateBasedRuleResponse(
    changeToken: Optional[ChangeToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse = {
    import DeleteRateBasedRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse
      .builder()
      .optionallyWith(
        changeToken.map(value => ChangeToken.unwrap(value): java.lang.String)
      )(_.changeToken)
      .build()
  }
  def asReadOnly
      : zio.aws.wafregional.model.DeleteRateBasedRuleResponse.ReadOnly =
    zio.aws.wafregional.model.DeleteRateBasedRuleResponse.wrap(buildAwsValue())
}
object DeleteRateBasedRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.DeleteRateBasedRuleResponse =
      zio.aws.wafregional.model
        .DeleteRateBasedRuleResponse(changeToken.map(value => value))
    def changeToken: Optional[ChangeToken]
    def getChangeToken: ZIO[Any, AwsError, ChangeToken] =
      AwsError.unwrapOptionField("changeToken", changeToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse
  ) extends zio.aws.wafregional.model.DeleteRateBasedRuleResponse.ReadOnly {
    override val changeToken: Optional[ChangeToken] = zio.aws.core.internal
      .optionalFromNullable(impl.changeToken())
      .map(value => zio.aws.wafregional.model.primitives.ChangeToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.DeleteRateBasedRuleResponse
  ): zio.aws.wafregional.model.DeleteRateBasedRuleResponse.ReadOnly =
    new Wrapper(impl)
}
